"use client";
import Link from "next/link";

import LoginForm from "@/ui/login/login-form";
import { useState } from "react";
import RegisterForm from "@/ui/login/register-form";
import styles from "./login.module.css";
import { useTranslations } from "next-intl";

type FormStatus = "login" | "register";
export default function Page() {
    const [formStatus, setFormStatus] = useState<FormStatus>("login");
    const t = useTranslations("pageFooter"); // 用于获取底部信息的翻译

    return (
        <main className="z-0 bg-ivory relative flex flex-col items-center pt-12 pb-5 px-4 md:px-24 w-full overflow-x-hidden">
            <video
                autoPlay
                muted
                loop
                playsInline
                className="absolute top-0 left-0 w-full h-full object-cover z-[-1]"
            >
                <source
                    src="https://file.typeframes.com.cn/video_2024-09-16 11_18_33.webm"
                    type="video/mp4"
                />
            </video>
            <article className="relative flex flex-col lg:flex-row gap-[80px] lg:gap-0 justify-evenly pt-[100px] lg:pt-0 mb-[120px] lg:mb-[30px] min-h-[calc(100vh_-_96px)] items-center">
                <section className="flex flex-col gap-[15px] items-center">
                    <Link className="mb-2" href="/">
                        {/* 在此处添加您的 Logo，如果有的话 */}
                    </Link>
                    <div className="text-info text-xl font-light my-4">
                        {t("welcome")} 👋
                    </div>
                    <section className={styles["login_form"]}>
                        {formStatus === "login" ? (
                            <LoginForm
                                toRegister={() => setFormStatus("register")}
                            />
                        ) : (
                            <RegisterForm back={() => setFormStatus("login")} />
                        )}
                    </section>
                </section>
            </article>

            {/* 底部版权信息 */}
            <footer className="w-full text-center text-gray-300 text-sm mt-4">
                <div>
                    &copy; {new Date().getFullYear()}{" "}
                    <span>{t("companyName")}</span> |{" "}
                    <span>{t("companyNameEn")}</span>
                </div>
                <div>
                    <a
                        href={t("domain1")}
                        target="_blank"
                        rel="noopener noreferrer"
                    >
                        {t("domain1")}
                    </a>{" "}
                    |{" "}
                    <a
                        href={t("domain2")}
                        target="_blank"
                        rel="noopener noreferrer"
                    >
                        {t("domain2")}
                    </a>
                </div>
                <div>{t("icpNumber")}</div>
            </footer>
        </main>
    );
}
